pub enum RawSyncOrStrippedState<C>{
Sync(Raw<SyncStateEvent<C>>),
Stripped(Raw<StrippedStateEvent<C::PossiblyRedacted>>),
}Expand description
Wrapper around both versions of a raw state event.
Variants
Sync(Raw<SyncStateEvent<C>>)
An event from a room in joined or left state.
Stripped(Raw<StrippedStateEvent<C::PossiblyRedacted>>)
An event from a room in invited state.
Implementations
Sourceimpl<C> RawSyncOrStrippedState<C>where
C: StaticStateEventContent + RedactContent,
C::Redacted: RedactedStateEventContent + Debug + Clone,
impl<C> RawSyncOrStrippedState<C>where
C: StaticStateEventContent + RedactContent,
C::Redacted: RedactedStateEventContent + Debug + Clone,
Sourcepub fn deserialize(&self) -> Result<SyncOrStrippedState<C>>where
C: StaticStateEventContent + EventContentFromType + RedactContent,
C::Redacted: RedactedStateEventContent<StateKey = C::StateKey> + EventContentFromType,
C::PossiblyRedacted: PossiblyRedactedStateEventContent + EventContentFromType,
pub fn deserialize(&self) -> Result<SyncOrStrippedState<C>>where
C: StaticStateEventContent + EventContentFromType + RedactContent,
C::Redacted: RedactedStateEventContent<StateKey = C::StateKey> + EventContentFromType,
C::PossiblyRedacted: PossiblyRedactedStateEventContent + EventContentFromType,
Try to deserialize the inner JSON as the expected type.